# Introduction
Juma Shafara
30-10-24

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Table of Contents

[Pushing files(artifacts) to Weights and Biases
(wandb)](00_push_data_to_wandb.ipynb)
